(internals)=

# Internals

```{warning}
Everything in this section is **internal implementation detail**. There is
no stability guarantee. Interfaces may change or be removed without notice
between any release.

If you are building workflows with vcspull, use the [CLI](../cli/index.md)
or refer to the [libvcs API](https://libvcs.git-pull.com/).
```

::::{grid} 1 1 2 2
:gutter: 2 2 3 3

:::{grid-item-card} Python API
:link: api/index
:link-type: doc
Internal module reference for contributors and plugin authors.
:::

:::{grid-item-card} CLI Internals
:link: api/cli/index
:link-type: doc
Python surface behind the CLI commands.
:::

::::

```{toctree}
:hidden:

api/index
api/cli/index
```
